[![CI Build](https://github.com/rstudio/gt-python/workflows/CI%20Tests/badge.svg?branch=main)](https://github.com/rstudio/gt-python/actions?query=workflow%3A%22CI+Tests%22+branch%3Amain)

With the **gt** package, anyone can make wonderful-looking tables with Python. The **gt** philosophy: we can construct a wide variety of useful tables with a cohesive set of table parts. These include the *table header*, the *stub*, the *column labels* and *spanner column labels*, the *table body*, and the *table footer*.

## Installation

```bash
$ pip install gt
```

## Contributing

Interested in contributing to **gt**? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## Code of Conduct

Please note that the gt project is released with a [contributor code of conduct](https://www.contributor-covenant.org/version/2/0/code_of_conduct/).<br>By participating in this project you agree to abide by its terms.

## 📄 License

**gt** is licensed under the MIT license. See the [`LICENSE`](LICENSE) file for more details.

© Posit Software, PBC.

## 🏛️ Governance

This project is primarily maintained by [Rich Iannone](https://twitter.com/riannone). Other authors may occasionally assist with some of these duties.
